@@ -44,7 +44,7 @@
 #include <QApplication>
 #include <QMessageBox>
 
-AssociationsDialog::AssociationsDialog( QWidget* parent, Qt::WFlags fl )
+AssociationsDialog::AssociationsDialog( QWidget* parent, Qt::WindowFlags fl )
     : QDialog( parent, fl ), graph(0)
 {
     setWindowTitle( tr( "Plot Associations" ) );
@@ -61,10 +61,17 @@ AssociationsDialog::AssociationsDialog( QWidget* parent, Qt::WFlags fl )
     vl->addLayout(hbox1);
 
 	table = new QTableWidget(3, 5);
+	table->verticalHeader()->hide();
+#if QT_VERSION >= 0x050000
+	table->horizontalHeader()->setSectionsClickable( false );
+	table->horizontalHeader()->setSectionResizeMode(QHeaderView::Stretch);
+	table->verticalHeader()->setSectionResizeMode(QHeaderView::ResizeToContents);
+#else
 	table->horizontalHeader()->setClickable( false );
 	table->horizontalHeader()->setResizeMode(QHeaderView::Stretch);
-	table->verticalHeader()->hide();
 	table->verticalHeader()->setResizeMode(QHeaderView::ResizeToContents);
+#endif
+
 	table->setMaximumHeight(8*table->rowHeight(0));
 	table->setHorizontalHeaderLabels(QStringList() << tr("Column") << tr("X") << tr("Y") << tr("xErr") << tr("yErr"));
     vl->addWidget(table);
@@ -117,8 +124,8 @@ void AssociationsDialog::updateCurves()
 
 void AssociationsDialog::changePlotAssociation(int curve, const QString& text)
 {
-  DataCurve *c = (DataCurve *)graph->curve(curve); //c_keys[curve]);
-  if (!c)
+  DataCurve *c = (DataCurve *)graph->curve(dataCurvesList[curve]); //c_keys[curve]);
+  if (!c || c->type()==Graph::Function)
     return;
 
   if (c->plotAssociation() == text)
@@ -180,7 +187,7 @@ for (int i=1; i < (int)cols.count(); i++ )
 return s;
 }
 
-void AssociationsDialog::initTablesList(QWidgetList* lst, int curve)
+void AssociationsDialog::initTablesList(QList<MyWidget*>* lst, int curve)
 {
 tables = lst;
 active_table = 0;
@@ -368,6 +375,7 @@ for (int i=0; i<graph->curves(); i++)
         QString s = ((DataCurve *)it)->plotAssociation();
         QString table = ((DataCurve *)it)->table()->name();
         plotAssociationsList << table + ": " + s.remove(table + "_");
+        dataCurvesList << i;
         }
 	}
 associations->addItems(plotAssociationsList);
