@@ -29,7 +29,6 @@
 #include "ApplicationWindow.h"
 #include "AxesDialog.h"
 #include "TextDialog.h"
-#include "ColorBox.h"
 #include "Graph.h"
 #include "Grid.h"
 #include "Plot.h"
@@ -63,8 +62,7 @@
 #define M_PI	3.141592653589793238462643
 #endif
 
-AxesDialog::AxesDialog( QWidget* parent, Qt::WFlags fl )
-: QDialog( parent, fl )
+AxesDialog::AxesDialog()
 {
 	QPixmap image4( ":/image4.xpm" );
 	QPixmap image5( ":/image5.xpm" );
@@ -72,14 +70,12 @@ AxesDialog::AxesDialog( QWidget* parent, Qt::WFlags fl )
 	QPixmap image7( ":/image7.xpm" );
 	setWindowTitle( tr( "General Plot Options" ) );
 
-	generalDialog = new QTabWidget();
-
 	initScalesPage();
 	initGridPage();
 	initAxesPage();
 	initFramePage();
 
-	QHBoxLayout * bottomButtons = new QHBoxLayout();
+	auto bottomButtons = new QHBoxLayout();
 	bottomButtons->addStretch();
 
 	buttonApply = new QPushButton();
@@ -95,17 +91,17 @@ AxesDialog::AxesDialog( QWidget* parent, Qt::WFlags fl )
 	buttonCancel->setText( tr( "&Cancel" ) );
 	bottomButtons->addWidget( buttonCancel );
 
-	QVBoxLayout * mainLayout = new QVBoxLayout(this);
-	mainLayout->addWidget(generalDialog);
+	QVBoxLayout* mainLayout = new QVBoxLayout(this);
+	mainLayout->addWidget(&generalDialog);
 	mainLayout->addLayout(bottomButtons);
-
+        
 	lastPage = scalesPage;
 
 	connect( buttonOk, SIGNAL( clicked() ), this, SLOT( accept() ) );
 	connect( buttonCancel, SIGNAL( clicked() ), this, SLOT( reject() ) );
 	connect( buttonApply, SIGNAL( clicked() ), this, SLOT(updatePlot() ) );
-	connect( generalDialog, SIGNAL( currentChanged ( QWidget * ) ),
-			this, SLOT(pageChanged ( QWidget * ) ) );
+	connect( &generalDialog, SIGNAL( currentChanged ( int ) ),
+			this, SLOT(pageChanged ( int ) ) );
 }
 
 void AxesDialog::initScalesPage()
@@ -203,7 +199,7 @@ void AxesDialog::initScalesPage()
 	mainLayout->addWidget(middleBox);
 	mainLayout->addWidget(rightBox);
 
-	generalDialog->addTab(scalesPage, tr( "Scale" ));
+	generalDialog.addTab(scalesPage, tr( "Scale" ));
 
 	connect(btnInvert,SIGNAL(clicked()), this, SLOT(updatePlot()));
 	connect(axesList,SIGNAL(currentRowChanged(int)), this, SLOT(updateScale()));
@@ -233,10 +229,10 @@ void AxesDialog::initGridPage()
 
 	rightLayout->addWidget( new QLabel(tr( "Line Color" )), 1, 0 );
 
-	boxColorMajor = new ColorBox(0);
+	boxColorMajor = new ColorButton();
 	rightLayout->addWidget( boxColorMajor, 1, 1);
 
-	boxColorMinor = new ColorBox(0);
+	boxColorMinor = new ColorButton();
 	boxColorMinor->setDisabled(true);
 	rightLayout->addWidget( boxColorMinor, 1, 2);
 
@@ -322,15 +318,15 @@ void AxesDialog::initGridPage()
 	mainLayout2->addWidget(axesGridList);
 	mainLayout2->addWidget(rightBox);
 
-	generalDialog->addTab( gridPage, tr( "Grid" ) );
+	generalDialog.addTab( gridPage, tr( "Grid" ) );
 
 	//grid page slot connections
     connect(axesGridList, SIGNAL(currentRowChanged(int)), this, SLOT(showGridOptions(int)));
 
 	connect(boxMajorGrid,SIGNAL(toggled(bool)), this, SLOT(majorGridEnabled(bool)));
 	connect(boxMinorGrid,SIGNAL(toggled(bool)), this, SLOT(minorGridEnabled(bool)));
-	connect(boxColorMajor,SIGNAL(activated(int)),this, SLOT(updateGrid()));
-	connect(boxColorMinor,SIGNAL(activated(int)),this, SLOT(updateGrid()));
+	connect(boxColorMajor,SIGNAL(changed(QColor)),this, SLOT(updateGrid()));
+	connect(boxColorMinor,SIGNAL(changed(QColor)),this, SLOT(updateGrid()));
 	connect(boxTypeMajor,SIGNAL(activated(int)),this, SLOT(updateGrid()));
 	connect(boxTypeMinor,SIGNAL(activated(int)),this, SLOT(updateGrid()));
 	connect(boxWidthMajor,SIGNAL(valueChanged (int)),this, SLOT(updateGrid()));
@@ -517,7 +513,7 @@ void AxesDialog::initAxesPage()
 	mainLayout3->addWidget( axesTitlesList );
 	mainLayout3->addLayout( rightLayout );
 
-	generalDialog->addTab( axesPage, tr( "Axis" ) );
+	generalDialog.addTab( axesPage, tr( "Axis" ) );
 
 	connect(buttonLabelFont, SIGNAL(clicked()), this, SLOT(customAxisLabelFont()));
 
@@ -593,7 +589,7 @@ void AxesDialog::initFramePage()
 	mainLayout->addWidget(boxFramed);
 	mainLayout->addWidget(boxAxes);
 
-	generalDialog->addTab(frame, tr( "General" ) );
+	generalDialog.addTab(frame, tr( "General" ) );
 
 	connect(boxFrameColor, SIGNAL(clicked()), this, SLOT(pickCanvasFrameColor()));
 	connect(boxBackbones, SIGNAL(toggled(bool)), this, SLOT(drawAxesBackbones(bool)));
@@ -606,7 +602,7 @@ void AxesDialog::initFramePage()
 
 void AxesDialog::changeMinorTicksLength (int minLength)
 {
-	if (generalDialog->currentWidget() != frame)
+	if (generalDialog.currentWidget() != frame)
 		return;
 
 	d_graph->changeTicksLength(minLength, boxMajorTicksLength->value());
@@ -615,7 +611,7 @@ void AxesDialog::changeMinorTicksLength (int minLength)
 
 void AxesDialog::changeMajorTicksLength (int majLength)
 {
-	if (generalDialog->currentWidget() != frame)
+	if (generalDialog.currentWidget() != frame)
 		return;
 
 	d_graph->changeTicksLength(boxMinorTicksLength->value(), majLength);
@@ -624,7 +620,7 @@ void AxesDialog::changeMajorTicksLength (int majLength)
 
 void AxesDialog::drawAxesBackbones(bool draw)
 {
-	if (generalDialog->currentWidget() != frame)
+	if (generalDialog.currentWidget() != frame)
 		return;
 
 	d_graph->drawAxesBackbones(draw);
@@ -632,7 +628,7 @@ void AxesDialog::drawAxesBackbones(bool draw)
 
 void AxesDialog::changeAxesLinewidth(int width)
 {
-	if (generalDialog->currentWidget() != frame)
+	if (generalDialog.currentWidget() != frame)
 		return;
 
 	d_graph->setAxesLinewidth(width);
@@ -640,7 +636,7 @@ void AxesDialog::changeAxesLinewidth(int width)
 
 void AxesDialog::drawFrame(bool framed)
 {
-	if (generalDialog->currentWidget() != frame)
+	if (generalDialog.currentWidget() != frame)
 		return;
 
 	d_graph->drawCanvasFrame(framed, boxFrameWidth->value(), boxFrameColor->color());
@@ -648,7 +644,7 @@ void AxesDialog::drawFrame(bool framed)
 
 void AxesDialog::updateFrame(int width)
 {
-	if (generalDialog->currentWidget() != frame)
+	if (generalDialog.currentWidget() != frame)
 		return;
 
 	d_graph->drawCanvasFrame(boxFramed->isChecked(), width, boxFrameColor->color());
@@ -1039,7 +1035,7 @@ void AxesDialog::minorGridEnabled(bool on)
 
 void AxesDialog::updateGrid()
 {
-  if (generalDialog->currentWidget() != gridPage)
+  if (generalDialog.currentWidget() != gridPage)
     return;
 
   Grid *grid = (Grid *)d_graph->plotWidget()->grid();
@@ -1050,17 +1046,17 @@ void AxesDialog::updateGrid()
     grid->enableX(boxMajorGrid->isChecked());
     grid->enableXMin(boxMinorGrid->isChecked());
 
-    grid->setMajPenX(QPen(ColorBox::color(boxColorMajor->currentIndex()), boxWidthMajor->value(),
+    grid->setMajPenX(QPen(boxColorMajor->color(), boxWidthMajor->value(),
                           Graph::getPenStyle(boxTypeMajor->currentIndex())));
-    grid->setMinPenX(QPen(ColorBox::color(boxColorMinor->currentIndex()), boxWidthMinor->value(),
+    grid->setMinPenX(QPen(boxColorMinor->color(), boxWidthMinor->value(),
                           Graph::getPenStyle(boxTypeMinor->currentIndex())));
   } else {
     grid->enableY(boxMajorGrid->isChecked());
     grid->enableYMin(boxMinorGrid->isChecked());
 
-    grid->setMajPenY(QPen(ColorBox::color(boxColorMajor->currentIndex()), boxWidthMajor->value(),
+    grid->setMajPenY(QPen(boxColorMajor->color(), boxWidthMajor->value(),
                           Graph::getPenStyle(boxTypeMajor->currentIndex())));
-    grid->setMinPenY(QPen(ColorBox::color(boxColorMinor->currentIndex()), boxWidthMinor->value(),
+    grid->setMinPenY(QPen(boxColorMinor->color(), boxWidthMinor->value(),
                           Graph::getPenStyle(boxTypeMinor->currentIndex())));
   }
 
@@ -1182,7 +1178,7 @@ void AxesDialog::changeBaselineDist(int baseline)
 
 bool AxesDialog::updatePlot()
 {
-	if (generalDialog->currentWidget()==(QWidget*)scalesPage)
+	if (generalDialog.currentWidget()==(QWidget*)scalesPage)
 	{
 		QString from=boxStart->text().toLower();
 		QString to=boxEnd->text().toLower();
@@ -1207,7 +1203,7 @@ bool AxesDialog::updatePlot()
 		try
 		{
 			MyParser parser;
-			parser.SetExpr(from.toAscii().constData());
+			parser.SetExpr(from.toUtf8().constData());
 			start=parser.Eval();
 		}
 		catch(mu::ParserError &e)
@@ -1219,7 +1215,7 @@ bool AxesDialog::updatePlot()
 		try
 		{
 			MyParser parser;
-			parser.SetExpr(to.toAscii().constData());
+			parser.SetExpr(to.toUtf8().constData());
 			end=parser.Eval();
 		}
 		catch(mu::ParserError &e)
@@ -1233,7 +1229,7 @@ bool AxesDialog::updatePlot()
 			try
 			{
 				MyParser parser;
-				parser.SetExpr(step.toAscii().constData());
+				parser.SetExpr(step.toUtf8().constData());
 				stp=parser.Eval();
 			}
 			catch(mu::ParserError &e)
@@ -1307,11 +1303,11 @@ bool AxesDialog::updatePlot()
 				boxScaleType->currentIndex(), btnInvert->isChecked());
 		d_graph->notifyChanges();
 	}
-	else if (generalDialog->currentWidget()==gridPage)
+	else if (generalDialog.currentWidget()==gridPage)
 	{
 		updateGrid();
 	}
-	else if (generalDialog->currentWidget()==(QWidget*)axesPage)
+	else if (generalDialog.currentWidget()==(QWidget*)axesPage)
 	{
 		int axis=mapToQwtAxisId();
 		int format = currentSelectedAxisType();
@@ -1333,7 +1329,7 @@ bool AxesDialog::updatePlot()
 						parser.DefineVar("x", &value);
 					else if (formula.contains("y"))
 						parser.DefineVar("y", &value);
-					parser.SetExpr(formula.toAscii().constData());
+					parser.SetExpr(formula.toUtf8().constData());
 					parser.Eval();
 				}
 				catch(mu::ParserError &e)
@@ -1383,7 +1379,7 @@ bool AxesDialog::updatePlot()
 				boxShowLabels->isChecked(), boxAxisColor->color(), boxFormat->currentIndex(),
 				boxPrecision->value(), boxAngle->value(), baseline, formula, boxAxisNumColor->color());
 	}
-	else if (generalDialog->currentWidget()==(QWidget*)frame)
+	else if (generalDialog.currentWidget()==(QWidget*)frame)
 	{
 		d_graph->setAxesLinewidth(boxAxesLinewidth->value());
 		d_graph->changeTicksLength(boxMinorTicksLength->value(), boxMajorTicksLength->value());
@@ -1735,22 +1731,22 @@ void AxesDialog::setCurrentScale(int axisPos)
 			axis = 2;
 			break;
 	}
-	if (generalDialog->currentWidget()==(QWidget*)scalesPage)
+	if (generalDialog.currentWidget()==(QWidget*)scalesPage)
 		axesList->setCurrentRow(axis);
-	else if (generalDialog->currentWidget()==(QWidget*)axesPage)
+	else if (generalDialog.currentWidget()==(QWidget*)axesPage)
 		axesTitlesList->setCurrentRow(axis);
 }
 
 void AxesDialog::showAxesPage()
 {
-	if (generalDialog->currentWidget()!=(QWidget*)axesPage)
-		generalDialog->setCurrentWidget(axesPage);
+	if (generalDialog.currentWidget()!=(QWidget*)axesPage)
+		generalDialog.setCurrentWidget(axesPage);
 }
 
 void AxesDialog::showGridPage()
 {
-	if (generalDialog->currentWidget()!=(QWidget*)gridPage)
-		generalDialog->setCurrentWidget(gridPage);
+	if (generalDialog.currentWidget()!=(QWidget*)gridPage)
+		generalDialog.setCurrentWidget(gridPage);
 }
 
 void AxesDialog::setLabelsNumericFormat(int)
@@ -1856,7 +1852,7 @@ void AxesDialog::updateLabelsFormat(int)
 
 void AxesDialog::showGeneralPage()
 {
-	generalDialog->setCurrentIndex(generalDialog->indexOf(frame));
+	generalDialog.setCurrentIndex(generalDialog.indexOf(frame));
 }
 
 void AxesDialog::showFormulaBox()
@@ -1877,17 +1873,18 @@ void AxesDialog::customAxisLabelFont()
 		d_graph->setAxisTitleFont(axis, fnt);
 }
 
-void AxesDialog::pageChanged ( QWidget *page )
+void AxesDialog::pageChanged ( int page )
 {
-	if (lastPage == scalesPage && page == axesPage)
+	QWidget* pageWidget = generalDialog.widget(page);
+	if (lastPage == scalesPage && pageWidget == axesPage)
 	{
 		axesTitlesList->setCurrentRow(axesList->currentRow());
-		lastPage = page;
+		lastPage = pageWidget;
 	}
-	else if (lastPage == axesPage && page == scalesPage)
+	else if (lastPage == axesPage && pageWidget == scalesPage)
 	{
 		axesList->setCurrentRow(axesTitlesList->currentRow());
-		lastPage = page;
+		lastPage = pageWidget;
 	}
 }
 
