@@ -60,14 +60,14 @@
 #include <gsl/gsl_linalg.h>
 #include <gsl/gsl_math.h>
 
-Matrix::Matrix(ScriptingEnv *env, int r, int c, const QString& label, QWidget* parent, const char* name, Qt::WFlags f)
+Matrix::Matrix(ScriptingEnv *env, int r, int c, const QString& label, QWidget* parent, const char* name, Qt::WindowFlags f)
 	: MatrixView(label, parent, name, f), scripted(env)
 {
 	d_future_matrix = new future::Matrix(0, r, c, label);
 	init(r, c);
 }
 	
-Matrix::Matrix(future::Matrix *future_matrix, ScriptingEnv *env, int r, int c, const QString& label, QWidget* parent, const char* name, Qt::WFlags f)
+Matrix::Matrix(future::Matrix *future_matrix, ScriptingEnv *env, int r, int c, const QString& label, QWidget* parent, const char* name, Qt::WindowFlags f)
 	: MatrixView(label, parent, name, f), scripted(env)
 {
 	d_future_matrix = future_matrix;
@@ -257,7 +257,7 @@ void Matrix::setNumericFormat(const QChar& f, int prec)
 	if (d_future_matrix->numericFormat() == f && d_future_matrix->displayedDigits() == prec)
 		return;
 
-	d_future_matrix->setNumericFormat(f.toAscii());
+	d_future_matrix->setNumericFormat(f.toLatin1());
 	d_future_matrix->setDisplayedDigits(prec);
 
 	emit modifiedWindow(this);
@@ -265,7 +265,7 @@ void Matrix::setNumericFormat(const QChar& f, int prec)
 
 void Matrix::setTextFormat(const QChar &format, int precision)
 {
-	d_future_matrix->setNumericFormat(format.toAscii());
+	d_future_matrix->setNumericFormat(format.toLatin1());
 	d_future_matrix->setDisplayedDigits(precision);
 }
 
