@@ -38,6 +38,8 @@
 #include "matrix/MatrixView.h"
 #include "lib/macros.h"
 
+#include <QPointer>
+
 class QContextMenuEvent;
 class QEvent;
 class ActionManager;
@@ -159,6 +161,7 @@ class Matrix : public AbstractPart
 		void setRowCells(int row, int first_column, int last_column, const QVector<qreal> & values);
 		//! Return the text displayed in the given cell
 		QString text(int row, int col);
+  using AbstractPart::copy;
 		void copy(Matrix * other);
 		double xStart() const;
 		double yStart() const;
@@ -290,6 +293,7 @@ class Matrix : public AbstractPart
 		void createActions();
 		void connectActions();
 		void addActionsToView();
+		void translateActionsStrings();
 
 		//! Read XML display element
 		bool readDisplayElement(XmlStreamReader * reader);
@@ -343,7 +347,7 @@ class Matrix : public AbstractPart
 		QAction * action_add_rows;
 		//@}
 
-		MatrixView *d_view;
+  QPointer<MatrixView> d_view;
 		Private *d_matrix_private;
 };
 
