@@ -1,26 +1,23 @@
 echo "old version=`git describe`"
-version=$1
-delta=${version##*.}
-# strip any leading 0s from delta
-delta=`echo $delta|sed -e 's/^0*//'`
+fullversion=$1
+version=${fullversion%%-*}
+extra=-${fullversion##*-}
+if [ $extra = "-$version" ]; then
+    extra=""
+fi
+echo $version $extra
+# strip any leading 0s from patch
 branch=${version%.*}
 major=${branch%.*}
-echo "$branch minor=$minor"
-if [ "$major" = "$branch" ]; then
-  # we have a full release, not beta release
-  minor=$delta
-  delta=0
-else
-  # we have a beta release
-  minor=${branch##*.}
-fi
-echo $major $minor $delta
-scidavis_version=$[$major*65536 + $minor*256 + $delta]
+minor=${branch#*.}
+patch=${version##*.}
+scidavis_version=$[$major*65536 + $minor*256 + $patch]
 rm -f libscidavis/src/version.cpp
 cat >libscidavis/src/version.cpp <<EOF
 #include "globals.h"
 const int SciDAVis::scidavis_versionNo = $scidavis_version;
 const char* SciDAVis::scidavis_version = "$version";
+const char* SciDAVis::extra_version = "$extra";
 const char * SciDAVis::release_date = "`date +"%b %d, %Y"`";
 EOF
 
@@ -37,6 +34,6 @@ done
 # update Doxyversion
 rm -f Doxyversion
 echo "PROJECT_NUMBER=$version" >Doxyversion
-echo "$1" >doc/version.tex
-git commit -a -m "Release $1"
-git tag -a -m "" $1
+echo "$version" >doc/version.tex
+git commit -a -m "Release $fullversion"
+git tag -a -m "" $fullversion
